@@ -13,6 +13,7 @@ mod electrum;
 pub mod file;
 mod onchain;
 pub mod psbt;
+mod sign;
 mod taptree;
 mod template;
 mod types;
@@ -21,12 +22,13 @@ mod unsatisfiable;
 mod wallet;
 mod xkey;
 
-pub use electrum::{ElectrumSec, ElectrumServer};
+pub use electrum::{ElectrumPreset, ElectrumSec, ElectrumServer};
 pub use file::FileDocument;
 pub use onchain::{
     AddressSource, AddressSummary, AddressValue, HistoryEntry, OnchainStatus, OnchainTxid, Prevout,
     UtxoTxid,
 };
+pub use sign::XprivSigner;
 pub use taptree::ToTapTree;
 pub use template::{Requirement, WalletTemplate};
 pub use types::{
