@@ -13,7 +13,9 @@ mod component;
 pub(self) mod sign_row;
 mod view_model;
 mod widget;
+pub(self) mod xpriv_dlg;
 
+use crate::model::PublicNetwork;
 use bitcoin::util::bip32::Fingerprint;
 use relm::StreamHandle;
 pub(super) use view_model::ModelParam;
@@ -30,15 +32,20 @@ pub enum Msg {
     Save,
     Launch(launch::Msg),
 
-    Sign(u32),
+    DeviceSign(u32),
+    XprivSign(u32),
     Signed(Psbt),
     Failed(String, Fingerprint, String),
 
+    Network(PublicNetwork),
+
     Publish,
     Published,
     Declined(String),
 
     RegisterLauncher(StreamHandle<launch::Msg>),
+
+    NoOp,
 }
 
 #[derive(Clone, Debug)]
