@@ -20,8 +20,7 @@ use relm::{init, Channel, Relm, StreamHandle, Update, Widget};
 
 use super::spending_row::Condition;
 use super::{xpub_dlg, Msg, ViewModel, Widgets};
-use crate::model::{PublicNetwork, Signer, WalletSettings};
-use crate::view::settings::view_model::ElectrumPreset;
+use crate::model::{ElectrumPreset, PublicNetwork, Signer, WalletSettings};
 use crate::view::{devices, error_dlg, launch, wallet, NotificationBoxExt};
 
 pub struct Component {
@@ -55,7 +54,6 @@ impl Component {
         if let Some(signer) = self.model.active_signer.clone() {
             self.widgets.replace_signer(&signer);
             debug_assert!(self.model.replace_signer(signer));
-            self.sync();
         }
     }
 
